@@ -3,16 +3,14 @@ from django.urls import reverse
 
 from django_quill.fields import QuillField
 
-__all__ = (
-    'QuillPost',
-)
+__all__ = ("QuillPost",)
 
 
 class QuillPost(models.Model):
     content = QuillField()
 
     class Meta:
-        ordering = ['-pk']
+        ordering = ["-pk"]
 
     def get_absolute_url(self):
-        return reverse('posts:quill-post-detail', args=[self.pk])
+        return reverse("posts:quill-post-detail", args=[self.pk])
